@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import Any, Dict, List, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, ValidationInfo, field_validator
 
 
 class TransactionRecordType(str, Enum):
@@ -15,6 +15,7 @@ class TransactionRecordType(str, Enum):
 
 class TransactionLoggingMethod(str, Enum):
     py_langchain = "py_langchain"
+    py_langchain_async = "py_langchain_async"
     py_logger = "py_logger"
 
 
@@ -36,11 +37,18 @@ class TransactionRecord(BaseModel):
     tags: Optional[List[str]] = None
     user_metadata: Optional[Dict[str, Any]] = None
     temperature: Optional[float] = None
-    constructor: Optional[str] = None
     node_type: TransactionRecordType
     has_children: bool = False
     version: Optional[str] = None
 
+    @field_validator("chain_id", mode="before")
+    def validate_chain_id(
+        cls, value: Optional[str], info: ValidationInfo
+    ) -> Optional[str]:
+        if value == info.data.get("node_id"):
+            raise ValueError("Chain ID cannot match node ID.")
+        return value
+
 
 class TransactionRecordBatch(BaseModel):
     records: List[TransactionRecord]
