@@ -1,14 +1,14 @@
 from enum import Enum
 from http.client import HTTPException
-from typing import Any, Callable, Dict, Optional, Union
-from urllib.parse import urljoin
+from typing import Any, Dict
 
-import backoff
-from requests import RequestException, Response
+from galileo_core.constants.request_method import RequestMethod
+from galileo_core.helpers.api_client import ApiClient
+from httpx import Response
 
 
-def _validate_response(response: Response) -> None:
-    if not response.ok:
+async def _validate_response(response: Response) -> None:
+    if not response.status_code < 300:
         msg = (
             "Something didn't go quite right. The api returned a non-ok status "
             f"code {response.status_code} with output: {response.text}"
@@ -17,29 +17,18 @@ def _validate_response(response: Response) -> None:
         raise HTTPException(msg)
 
 
-@backoff.on_exception(backoff.expo, RequestException, max_tries=4, jitter=None)
-def make_request(
-    request_method: Callable,
+async def make_request(
+    request_method: RequestMethod,
     base_url: str,
     endpoint: str,
-    body: Optional[Dict] = None,
-    data: Optional[Dict] = None,
-    files: Optional[Dict] = None,
-    params: Optional[Dict] = None,
-    headers: Optional[Dict[str, str]] = None,
-    timeout: Union[int, None] = None,
+    **kwargs: Any,
 ) -> Any:
-    response = request_method(
-        urljoin(base_url, endpoint),
-        json=body,
-        data=data,
-        files=files,
-        params=params,
-        headers=headers or {},
-        timeout=timeout,
+    return await ApiClient.make_request(
+        request_method=request_method,
+        base_url=base_url,
+        endpoint=endpoint,
+        **kwargs,
     )
-    _validate_response(response)
-    return response.json()
 
 
 class HttpHeaders(str, Enum):
